<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'mega_tour_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery','mega-tour-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback'   => 'mega_tour_pro_is_gallery_panel_enable',

) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_gallery_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// Gallery sub title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[gallery_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[gallery_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_gallery_section',
	'active_callback' 	=> 'mega_tour_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// gallery title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[gallery_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_gallery_section',
	'active_callback' 	=> 'mega_tour_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[gallery_title]', array(
		'selector'            => '#our-gallery .section-header h2.section-title',
		'settings'            => 'mega_tour_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_gallery_title_partial',
    ) );
}

// Gallery title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[gallery_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_gallery_section',
	'active_callback' 	=> 'mega_tour_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[gallery_title]', array(
		'selector'            => '#our-gallery .section-header h2.section-title',
		'settings'            => 'mega_tour_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_gallery_title_partial',
    ) );
}

// Gallery Content type setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_gallery_section_enable',
	'choices'			=> mega_tour_pro_gallery_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Category_Control( $wp_customize,'mega_tour_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Multiple Category', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_gallery_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'mega_tour_pro_is_gallery_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[gallery_content_trip_types]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Category_Control( $wp_customize,'mega_tour_pro_theme_options[gallery_content_trip_types]', array(
	'label'             => esc_html__( 'Select Multiple Trip Types', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_gallery_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'mega_tour_pro_is_gallery_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[gallery_content_activity]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Category_Control( $wp_customize,'mega_tour_pro_theme_options[gallery_content_activity]', array(
	'label'             => esc_html__( 'Select Multiple Activities', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_gallery_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'mega_tour_pro_is_gallery_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[gallery_content_destination]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Category_Control( $wp_customize,'mega_tour_pro_theme_options[gallery_content_destination]', array(
	'label'             => esc_html__( 'Select Multiple Destination', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_gallery_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'mega_tour_pro_is_gallery_section_content_destination_enable'
) ) );