<?php
/**
 * partner Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add partner section
$wp_customize->add_section( 'mega_tour_pro_partner_section', array(
	'title'             => esc_html__( 'Partner','mega-tour-pro' ),
	'description'       => esc_html__( 'Partner Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback'   => 'mega_tour_pro_is_partner_panel_enable',

) );

// partner content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_section_enable]', array(
	'default'			=> 	$options['partner_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[partner_section_enable]', array(
	'label'             => esc_html__( 'partner Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_partner_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// partner auto play enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_auto_play]', array(
	'default'			=> 	$options['partner_auto_play'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[partner_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_partner_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_sub_title]', array(
    'default'           => $options['partner_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[partner_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_partner_section',
	'active_callback' 	=> 'mega_tour_pro_is_partner_section_enable',
	'type'				=> 'text',
) );

// Partner title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['partner_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[partner_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_partner_section',
	'active_callback' 	=> 'mega_tour_pro_is_partner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[partner_title]', array(
		'selector'            => '#our-partners .wrapper h2.section-title',
		'settings'            => 'mega_tour_pro_theme_options[partner_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_partner_title_partial',
    ) );
}


// partner  background image setting and control.
$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_bg_image]', array(
	'default'           =>$options['partner_bg_image'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_tour_pro_theme_options[partner_bg_image]',
		array(
		'label'       		=> esc_html__( 'Partner Background Image', 'mega-tour-pro'),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-tour-pro' ), 1920, 600 ),
		'section'     		=> 'mega_tour_pro_partner_section',
		'active_callback'	=> 'mega_tour_pro_is_partner_section_enable',
) ) );


// Partner post  number control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_count]', array(
	'default'          	=> $options['partner_count'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_number_range',
	//'validate_callback' => 'mega_tour_pro_validate_partner_count',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[partner_count]', array(
	'label'             => esc_html__( 'Number of partners', 'mega-tour-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_partner_section',
	'active_callback'   => 'mega_tour_pro_is_partner_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// partner content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_content_type]', array(
	'default'          	=> $options['partner_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[partner_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_partner_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_partner_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-tour-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-tour-pro' ),
		'category' 	=> esc_html__( 'Category', 'mega-tour-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'mega-tour-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[partner_content_category]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[partner_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-tour-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_partner_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_partner_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['partner_count']; $i++ ) :
	// partner pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[partner_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_partner_section',
		'choices'			=> mega_tour_pro_page_choices(),
		'active_callback'	=> 'mega_tour_pro_is_partner_section_content_page_enable',
	) ) );

	// partner posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[partner_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_partner_section',
		'choices'			=> mega_tour_pro_post_choices(),
		'active_callback'	=> 'mega_tour_pro_is_partner_section_content_post_enable',
	) ) );

	// partner image setting and control.
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_image_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_tour_pro_theme_options[partner_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'mega-tour-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-tour-pro' ), 700, 600 ),
			'section'     		=> 'mega_tour_pro_partner_section',
			'active_callback'	=> 'mega_tour_pro_is_partner_section_content_custom_enable',
	) ) );

	// partner position setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'mega_tour_pro_theme_options[partner_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'mega-tour-pro' ), $i ),
		'section'        	=> 'mega_tour_pro_partner_section',
		'active_callback' 	=> 'mega_tour_pro_is_partner_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// partner hr setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[partner_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Customize_Horizontal_Line( $wp_customize, 'mega_tour_pro_theme_options[partner_hr_'. $i .']',
		array(
			'section'         => 'mega_tour_pro_partner_section',
			'active_callback' => 'mega_tour_pro_is_partner_section_content_hr_enable',
			'type'			  => 'hr'
	) ) );
endfor;

