<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'mega_tour_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','mega-tour-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback'   => 'mega_tour_pro_is_testimonial_panel_enable',

) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_testimonial_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// Testimonial auto play enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_auto_play]', array(
	'default'			=> 	$options['testimonial_auto_play'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[testimonial_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_testimonial_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[testimonial_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_testimonial_section',
	'active_callback' 	=> 'mega_tour_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// testimonial title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_testimonial_section',
	'active_callback' 	=> 'mega_tour_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[testimonial_title]', array(
		'selector'            => '#testimonial-section .section-header h2.section-title',
		'settings'            => 'mega_tour_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_testimonial_title_partial',
    ) );
}

// Testimonial post  number control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_number_range',
	'validate_callback' => 'mega_tour_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'mega-tour-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_testimonial_section',
	'active_callback'   => 'mega_tour_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-tour-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-tour-pro' ),
		'category' 	=> esc_html__( 'Category', 'mega-tour-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'mega-tour-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-tour-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_testimonial_section',
		'choices'			=> mega_tour_pro_page_choices(),
		'active_callback'	=> 'mega_tour_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_testimonial_section',
		'choices'			=> mega_tour_pro_post_choices(),
		'active_callback'	=> 'mega_tour_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial author setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_author_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_tour_pro_theme_options[testimonial_author_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Author Name %d', 'mega-tour-pro' ), $i ),
		'section'        	=> 'mega_tour_pro_testimonial_section',
		'active_callback' 	=> 'mega_tour_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );

	
	// testimonial position setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_tour_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'mega-tour-pro' ), $i ),
		'section'        	=> 'mega_tour_pro_testimonial_section',
		'active_callback' 	=> 'mega_tour_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'mega_tour_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'mega-tour-pro' ), $i ),
		'section'        	=> 'mega_tour_pro_testimonial_section',
		'active_callback' 	=> 'mega_tour_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_tour_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'mega-tour-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-tour-pro' ), 700, 600 ),
			'section'     		=> 'mega_tour_pro_testimonial_section',
			'active_callback'	=> 'mega_tour_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'mega_tour_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'mega-tour-pro' ), $i ),
		'section'        	=> 'mega_tour_pro_testimonial_section',
		'active_callback' 	=> 'mega_tour_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Customize_Horizontal_Line( $wp_customize, 'mega_tour_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'mega_tour_pro_testimonial_section',
			'active_callback' => 'mega_tour_pro_is_testimonial_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

