<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Mega Tour Pro 1.0.0
    */
    function mega_tour_pro_add_about_section() {
        $options = mega_tour_pro_get_theme_options();
        
        // Check if About is enabled on frontpage
        $about_enable = apply_filters( 'mega_tour_pro_section_status', true, 'about_section_enable' );

        if( $options['home_layout'] == 'fourth-design'){
            $about_enable = false;
        }
        if ( true !== $about_enable ) {
            return false;
        }
        $section_details = array();

        // Get About section details
        $section_details = apply_filters( 'mega_tour_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        switch ( $options['home_layout'] ) {
            case 'default-design':
                // Render About default design section .
                mega_tour_pro_render_about_section( $section_details );
                break;
            
            case 'third-design':
                // Render About business section .
                mega_tour_pro_render_business_about_section( $section_details );
                break;
            
            default:
                // Render About default design section .
                mega_tour_pro_render_about_section( $section_details );
        }

    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_about_section_details' ) ) :
    /**
    * About section details.
    *
    * @since Mega Tour Pro 1.0.0
    * @param array $input about section details.
    */
    function mega_tour_pro_get_about_section_details( $input ) {
        $options = mega_tour_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['url']          = ! empty( $options['about_btn_link'] ) ? $options['about_btn_link'] : '';
                $custom['image']          = ! empty( $options['about_image'] ) ? $options['about_image'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            case 'trip':
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$post_id = ! empty( $options['about_content_trip']) ? $options['about_content_trip'] : '';

				$args = array(
					'post_type'         => 'itineraries',
                    'p'                 =>  $post_id,
                    'posts_per_page'    => 1,
                    
					);   

			break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = ( $options['home_layout'] == 'third-design') ? mega_tour_pro_trim_content( 75 ) : mega_tour_pro_trim_content( 35 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// About section content details.
add_filter( 'mega_tour_pro_filter_about_section_details', 'mega_tour_pro_get_about_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_about_section' ) ) :
  /**
   * Start About section
   *
   * @return string About content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_about_section( $content_details = array() ) {
        $options = mega_tour_pro_get_theme_options();
        $about_sub_title = ! empty( $options['about_sub_title'] ) ? $options['about_sub_title'] : ' ';
        $about_btn_title = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : esc_html__( 'Explore More', 'mega-tour-pro' );
        $about_video_url = ! empty( $options['about_video_url'] ) ? $options['about_video_url'] : '';


        $content = $content_details[0];
        if ( empty( $content_details ) ) {
            return;
        } 
        ?>

        <div id="about-us" class="relative page-section">
            <div class="wrapper">
                <article class="has-post-thumbnail">
                    <div class="featured-image" style="background-image: url(<?php echo esc_url($content['image']);?>)">
                    <?php if(!empty($about_video_url)): ?>
                        <div class="video-popup">
                            <a href="<?php echo esc_url($about_video_url); ?>" class="video-link">
                            <?php echo mega_tour_pro_get_svg(array('icon'=>'play-circle')); ?>
                            </a>
                        </div><!-- .video-popup -->
                    <?php endif; ?>
                    </div><!-- .featured-image -->

                    <div class="entry-container">
                        <header class="entry-header">
                            <p class="subtitle"><?php echo esc_html($about_sub_title); ?></p>
                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                        </header>

                        <div class="entry-content">
                            <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                        </div><!-- .entry-content -->
                        <?php if($options['about_section_counter_enable']): ?>
                        <div class="counter-wrapper clear">
                            <?php for($i = 1; $i<=4; $i++):
                            if(empty($options['about_counter_'.$i.'']) || empty($options['about_counter_title_'.$i.''])) break; ?>
                            <div class="counter-item">
                                <h3 class="counter-value"><?php echo esc_html($options['about_counter_'.$i.'']); ?></h3>
                                <span class="counter-title"><?php echo esc_html($options['about_counter_title_'.$i.'']); ?></span>
                            </div><!-- .counter-item -->
                            <?php endfor; ?>
                        </div><!-- .counter-wrapper -->  
                        <?php endif;
                        
                        if(!empty($about_btn_title)): ?>
                        <div id="about-us-read-more" class="read-more">
                            <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($about_btn_title); ?></a>
                        </div><!-- .read-more -->
                        <?php endif; ?>
                    </div><!-- .entry-container -->
                </article>
            </div><!-- .wrapper -->
            </div><!-- #about-us -->

        <?php 
    }
endif;

if ( ! function_exists( 'mega_tour_pro_render_business_about_section' ) ) :
  /**
   * Start About Business Design Section
   *
   * @return string About content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_business_about_section( $content_details = array() ) {
        $options = mega_tour_pro_get_theme_options();
        $about_btn_title = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : esc_html__( 'Explore More', 'mega-tour-pro' );
        $about_bg_image = ! empty( $options['about_bg_image'] ) ? $options['about_bg_image'] : '#';
        $content = $content_details[0];
        if ( empty( $content_details ) ) {
            return;
        } 
        ?>

    <div id="business-about-us" class="relative page-section">
        <div class="wrapper">
            <article class="has-post-thumbnail">
                <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']);?>');">
                    <a href="<?php echo esc_url($content['url']); ?>" class="post-thumbnail-link"></a>
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                    </header>

                    <div class="entry-content">
                        <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                    </div><!-- .entry-content -->

                    <?php if(!empty($about_btn_title)): ?>
                        <div id="about-us-read-more" class="business-read-more">
                            <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($about_btn_title); ?></a>
                        </div><!-- .business-read-more -->
                    <?php endif; ?>

                </div><!-- .entry-container -->
            </article>
        </div><!-- .wrapper -->
    </div><!-- #business-about-us -->
    <?php if($options['about_section_counter_enable']): ?>
    <div id="business-counter" class="relative page-section" style="background-image: url('<?php echo esc_url($about_bg_image); ?>');">
        <div class="overlay"></div>
        <div class="wrapper">
            <div class="business-section-content clear col-4">
            <?php for($i = 1; $i<=4; $i++):
                    if(empty($options['about_counter_'.$i.'']) || empty($options['about_counter_title_'.$i.''])) break; ?>
                        <article>
                            <header class="entry-header">
                                <h3 class="counter-value"><?php echo esc_html($options['about_counter_'.$i.'']); ?></h3>
                                <div class="separator-line"></div>
                                <h2 class="entry-title"><?php echo esc_html($options['about_counter_title_'.$i.'']); ?></h2>
                            </header>
                        </article>
                <?php endfor; ?>
            </div><!-- .business-section-content -->
        </div><!-- .wrapper -->
    </div><!-- #business-counter -->  
    <?php endif; ?>

        <?php 
    }
endif;