<?php
/**
 * Blog Featured section
 *
 * This is the template for the content of Blog Featured section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_blog_featured_section' ) ) :
    /**
    * Add Blog Featured section
    *
    *@since Mega Tour Pro 1.0.0
    */
    function mega_tour_pro_add_blog_featured_section() {
        $options = mega_tour_pro_get_theme_options();
        
        // Check if Blog Featured is enabled on frontpage
        $blog_featured_enable = apply_filters( 'mega_tour_pro_section_status', true, 'blog_featured_section_enable' );

        if($options['home_layout'] != 'fourth-design'){
            $blog_featured_enable = false;
        }
        if ( true !== $blog_featured_enable  ) {
            return false;
        }
        // Get Blog Featured section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_pro_filter_blog_featured_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        
        //Render Blog Featured Section
        mega_tour_pro_render_blog_featured_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_blog_featured_section_details' ) ) :
    /**
    * Blog Featured section details.
    *
    * @since Mega Tour Pro 1.0.0
    * @param array $input blog section details.
    */
    function mega_tour_pro_get_blog_featured_section_details( $input ) {
        $options = mega_tour_pro_get_theme_options();

        $blog_featured_content_type  = $options['blog_featured_content_type']; // Blog Featured Content type.
        $blog_featured_count = ! empty( $options['blog_featured_count'] ) ? $options['blog_featured_count'] : 3; // Blog Featured Count.
        
        $content = array();
        switch ( $blog_featured_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_featured_count; $i++ ) {
                    if ( ! empty( $options['blog_featured_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_featured_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_featured_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_featured_count; $i++ ) {
                    if ( ! empty( $options['blog_featured_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_featured_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_featured_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_featured_content_category'] ) ? $options['blog_featured_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_featured_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
                break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '#'; 

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

//  Blog Featured  section content details.
add_filter( 'mega_tour_pro_filter_blog_featured_section_details', 'mega_tour_pro_get_blog_featured_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_blog_featured_section' ) ) :
  /**
   * Start  Blog Featured  section
   *
   * @return string Blog Featured content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_blog_featured_section( $content_details = array() ) {
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="blog-featured-posts" class="relative page-section">
            <div class="wrapper">
                <div class="blog-section-content clear">
                    <?php foreach($content_details as $content) :?>
                    <article>
                        <div class="blog-featured-item" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_html($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                            </header>
                        </div><!-- .blog-featured-item -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- .blog-section-content -->
            </div><!-- .wrapper -->
        </div><!-- #blog-featured-posts -->
    <?php }
endif;
