<?php
/**
 * Gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Mega Tour Pro 1.0.0
    */
    function mega_tour_pro_add_gallery_section() {
        $options = mega_tour_pro_get_theme_options();

        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'mega_tour_pro_section_status', true, 'gallery_section_enable' );

        if( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design'){
            $gallery_enable = false;
        }
        if ( true !== $gallery_enable ) {
           return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_pro_filter_gallery_section_details', $section_details );
        if ( empty( $section_details ) ) {
           return;
        }
        // Render gallery section now.
        mega_tour_pro_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_gallery_section_details' ) ) :
    /**
    * Gallery section details.
    *
    * @since Mega Tour Pro 1.0.0
    * @param array $input gallery section details.
    */
    function mega_tour_pro_get_gallery_section_details( $input ) {
        $options = mega_tour_pro_get_theme_options();

        // Content type.
        $gallery_content_type  = $options['gallery_content_type'];
        $content = array();
        $args = array();
        $content['cats'] = array();
        switch ( $gallery_content_type ) {
        	
            case 'category':
                $cat_ids = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'         => 'post',
                        'posts_per_page'    => 6,
                        'cat'               => absint( $cat_id ),
                        'ignore_sticky_posts'   => true,
                        );
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;               
                $content['taxonomy'] = 'category';
            break;

            case 'trip-types': // trip-types
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = ! empty( $options['gallery_content_trip_types'] ) ? $options['gallery_content_trip_types'] : array();
                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'      => 'itineraries',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'itinerary_types',
                                'field'    => 'id',
                                'terms'    => $cat_id,
                            ),
                        ),
                        'posts_per_page'  => 6,
                        );
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;                
                $content['taxonomy'] = 'itinerary_types';
            break;

            case 'destination'://Destination
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = ! empty( $options['gallery_content_destination'] ) ? $options['gallery_content_destination'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'      => 'itineraries',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'travel_locations',
                                'field'    => 'id',
                                'terms'    => $cat_id,
                            ),
                        ),
                        'posts_per_page'  => 6,
                        ); 
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;                   
                $content['taxonomy'] = 'travel_locations';
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_ids = ! empty( $options['gallery_content_activity'] ) ? $options['gallery_content_activity'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'      => 'itineraries',
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'activity',
                                'field'    => 'id',
                                'terms'    => $cat_id,
                            ),
                        ),
                        'posts_per_page'  => 6,
                        ); 
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;                   
                $content['taxonomy'] = 'activity';
            break;

            default:
            break;
        }

        $i = 0;
        foreach ( $args as $arg ) :
            $content['details'][$i] = array();
            // Run The Loop.
            $query = new WP_Query( $arg );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post[$i]['id']        = get_the_id();
                    $page_post[$i]['title']     = get_the_title();
                    $page_post[$i]['url']       = get_the_permalink();
                    $page_post[$i]['image']  	 = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content['details'][$i], $page_post[$i] );
                endwhile;
            endif;
            wp_reset_postdata();
            $i++;
        endforeach;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'mega_tour_pro_filter_gallery_section_details', 'mega_tour_pro_get_gallery_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_gallery_section' ) ) :
  /**
   * Start Gallery section
   *
   * @return string Gallery content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_gallery_section( $content_details = array() ) {
        $options = mega_tour_pro_get_theme_options();
        $gallery_title = ! empty( $options['gallery_title'] ) ? $options['gallery_title'] : esc_html__( 'Moment to Remember', 'mega-tour-pro' );
        $gallery_sub_title = ! empty( $options['gallery_sub_title'] ) ? $options['gallery_sub_title'] : esc_html__( 'Moment to Remember', 'mega-tour-pro' );
        $gallery_content_type = $options['gallery_content_type'];
        
        ?>
            <div id="our-gallery" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header">
                        <p class="subtitle"><?php echo esc_html($gallery_sub_title); ?></p>
                        <h2 class="section-title"><?php echo esc_html($gallery_title); ?></h2>
                    </div><!-- .section-header -->
                    <ul class="tabs">
                    <li class="active" data-tab="all"><?php esc_html_e('All', 'mega-tour-pro')?></li>
                    <?php 
                    foreach ( $content_details['cats'] as $i=>$content ) :
                        $terms =  get_term_by( 'id', $content, $content_details['taxonomy'] ); 
                        if(!is_wp_error( $terms ) && $terms): ?>
                            <li data-tab="<?php echo esc_attr($terms->slug); ?>" ><?php echo esc_html( $terms->name ); ?></li>
                    <?php endif; 
                    endforeach; ?>
                    </ul>
                    <div class="section-content gallery-popup">
                    <?php foreach ( $content_details['details'] as $i => $content_detail ) : 
                        $catid =  $content_details['cats'][$i];
                        $cat = get_term_by( 'id', $catid, $content_details['taxonomy']);  ?>
                        <div id="<?php echo esc_attr($cat->slug); ?>" class="tab-content grid">
                            <?php foreach ( $content_detail as $content ) : ?>
                            <article class="grid-item">
                                <div class="gallery-item-wrapper">
                                    <div class="gallery-overlay">
                                        <div class="overlay-bg"></div>
                                    </div><!-- .gallery-overlay -->

                                    <div class="featured-image" style="background-image: url(<?php echo esc_url($content['image']); ?>);"></div>
                                    <a href="<?php echo esc_url($content['image']); ?>" class="popup"><i class="fa fa-search"></i></a>
                                </div><!-- .gallery-item -->
                            </article>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #our-gallery -->

    <?php }
endif;